Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DefaultStatePath ¶
func DefaultStatePath() string
DefaultStatePath returns the default state file path.
func DescriptionKey ¶
DescriptionKey returns the key used for storing a feature's description.
Types ¶
type State ¶
type State struct {
Descriptions map[string]string `yaml:"descriptions,omitempty"`
// contains filtered or unexported fields
}
State holds persistent metadata that is not part of the config.
func (*State) DeleteDescription ¶
DeleteDescription removes a description entry.
func (*State) GetDescription ¶
GetDescription returns the description for the given key.
func (*State) SetDescription ¶
SetDescription sets or updates a description.
Click to show internal directories.
Click to hide internal directories.